import openai
import time

test_number = 10
try:
    openai.FileSet(f"chris_test{test_number}").delete()
except:
    pass


# Creation
openai.FileSet.create(
    name=f"chris_test{test_number}", file_ids=["file-x6c4dy5ULysgpu1PJCIudyeX"]
)

# List
openai.FileSet.list()

# GET
openai.FileSet.retrieve(f"chris_test{test_number}")

# Deletion
openai.FileSet.retrieve(f"chris_test{test_number}").delete()

# Delete the other way
openai.FileSet.create(name=f"chris_test{test_number}")
# print("waiting")

# time.sleep(5)
openai.FileSet(f"chris_test{test_number}").delete()



from openai.api_resources.abstract import (
    ListableAPIResource,
    CreateableAPIResource,
    nested_resource_class_methods,
)
from openai.six.moves.urllib.parse import quote_plus
from openai import util


@nested_resource_class_methods("event", operations=["list"])
class FineTune(ListableAPIResource, CreateableAPIResource):
    OBJECT_NAME = "fine-tune"

    @classmethod
    def cancel(cls, id, api_key=None, request_id=None, **params):
        base = cls.class_url()
        extn = quote_plus(id)
        url = "%s/%s/cancel" % (base, extn)
        instance = cls(id, api_key, **params)
        headers = util.populate_headers(request_id=request_id)
        return instance.request("post", url, headers=headers)